<?php

namespace Kependudukan\KB\Http\Controllers;
use Litepie\KB\Http\Requests\ProvinceRequest;
use Litepie\KB\Models\Province;

trait ProvinceWorkflow {
	
    /**
     * Workflow controller function for province.
     *
     * @param Model   $province
     * @param step    next step for the workflow.
     *
     * @return Response
     */

    public function putWorkflow(ProvinceRequest $request, Province $province, $step)
    {

        try {

            $province->updateWorkflow($step);

            return response()->json([
                'message'  => trans('messages.success.changed', ['Module' => trans('k_b::province.name'), 'status' => trans("app.{$step}")]),
                'code'     => 204,
                'redirect' => trans_url('/admin/province/province/' . $province->getRouteKey()),
            ], 201);

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
                'redirect' => trans_url('/admin/province/province/' . $province->getRouteKey()),
            ], 400);

        }

    }

    /**
     * Workflow controller function for province.
     *
     * @param Model   $province
     * @param step    next step for the workflow.
     * @param user    encrypted user id.
     *
     * @return Response
    */

    public function getWorkflow(Province $province, $step, $user)
    {
        try {
            $user_id = decrypt($user);

            Auth::onceUsingId($user_id);

            $province->updateWorkflow($step);

            $data = [
                'message' => trans('messages.success.changed', ['Module' => trans('k_b::province.name'), 'status' => trans("app.{$step}")]),
                'status'  => 'success',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('k_b::admin.province.message', $data)->render();

        } catch (ValidationException $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b> <br /><br />' . implode('<br />', $e->validator->errors()->all()),
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('k_b::admin.province.message', $data)->render();

        } catch (Exception $e) {

            $data = [
                'message' => '<b>' . $e->getMessage(). '</b>',
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('k_b::admin.province.message', $data)->render();

        }

    }
}