<?php

namespace Kependudukan\KB\Providers;

use Illuminate\Support\ServiceProvider;

class KBServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../../../resources/views', 'k_b');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../../../resources/lang', 'k_b');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        // Bind facade
        $this->app->bind('k_b', function ($app) {
            return $this->app->make('Kependudukan\KB\KB');
        });

        // Bind Province to repository
        $this->app->bind(
            \Kependudukan\KB\Interfaces\ProvinceRepositoryInterface::class,
            \Kependudukan\KB\Repositories\Eloquent\ProvinceRepository::class
        );

        $this->app->register(\Kependudukan\KB\Providers\AuthServiceProvider::class);
        $this->app->register(\Kependudukan\KB\Providers\EventServiceProvider::class);
        $this->app->register(\Kependudukan\KB\Providers\RouteServiceProvider::class);
        // $this->app->register(\Kependudukan\KB\Providers\WorkflowServiceProvider::class);
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['k_b'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../../../config/config.php' => config_path('kependudukan/k_b.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../../../resources/views' => base_path('resources/views/vendor/k_b')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../../../resources/lang' => base_path('resources/lang/vendor/k_b')], 'lang');

        // Publish migrations
        $this->publishes([__DIR__ . '/../../../../database/migrations/' => base_path('database/migrations')], 'migrations');

        // Publish seeds
        $this->publishes([__DIR__ . '/../../../../database/seeds/' => base_path('database/seeds')], 'seeds');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
