<?php

namespace Kependudukan\KB\Workflow;

use Exception;
use Litepie\Workflow\Exceptions\WorkflowActionNotPerformedException;

use Kependudukan\KB\Models\Province;

class ProvinceAction
{
    /**
     * Perform the complete action.
     *
     * @param Province $province
     *
     * @return Province
     */
    public function complete(Province $province)
    {
        try {
            $province->status = 'complete';
            return $province->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the verify action.
     *
     * @param Province $province
     *
     * @return Province
     */public function verify(Province $province)
    {
        try {
            $province->status = 'verify';
            return $province->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the approve action.
     *
     * @param Province $province
     *
     * @return Province
     */public function approve(Province $province)
    {
        try {
            $province->status = 'approve';
            return $province->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the publish action.
     *
     * @param Province $province
     *
     * @return Province
     */public function publish(Province $province)
    {
        try {
            $province->status = 'publish';
            return $province->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the archive action.
     *
     * @param Province $province
     *
     * @return Province
     */
    public function archive(Province $province)
    {
        try {
            $province->status = 'archive';
            return $province->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the unpublish action.
     *
     * @param Province $province
     *
     * @return Province
     */
    public function unpublish(Province $province)
    {
        try {
            $province->status = 'unpublish';
            return $province->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }
}
