<?php

namespace Kependudukan\KB\Workflow;

use Kependudukan\KB\Models\Province;
use Validator;

class ProvinceValidator
{

    /**
     * Determine if the given province is valid for complete status.
     *
     * @param Province $province
     *
     * @return bool / Validator
     */
    public function complete(Province $province)
    {
        return Validator::make($province->toArray(), [
            'title' => 'required|min:15',
        ]);
    }

    /**
     * Determine if the given province is valid for verify status.
     *
     * @param Province $province
     *
     * @return bool / Validator
     */
    public function verify(Province $province)
    {
        return Validator::make($province->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:complete',
        ]);
    }

    /**
     * Determine if the given province is valid for approve status.
     *
     * @param Province $province
     *
     * @return bool / Validator
     */
    public function approve(Province $province)
    {
        return Validator::make($province->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:verify',
        ]);

    }

    /**
     * Determine if the given province is valid for publish status.
     *
     * @param Province $province
     *
     * @return bool / Validator
     */
    public function publish(Province $province)
    {
        return Validator::make($province->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,archive,unpublish',
        ]);

    }

    /**
     * Determine if the given province is valid for archive status.
     *
     * @param Province $province
     *
     * @return bool / Validator
     */
    public function archive(Province $province)
    {
        return Validator::make($province->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,publish,unpublish',
        ]);

    }

    /**
     * Determine if the given province is valid for unpublish status.
     *
     * @param Province $province
     *
     * @return bool / Validator
     */
    public function unpublish(Province $province)
    {
        return Validator::make($province->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:publish',
        ]);

    }
}
